@@ -80,6 +80,12 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -128,7 +134,8 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -236,6 +243,12 @@ class DATA_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -412,6 +425,12 @@ class DATA_PT_bone_groups(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -562,6 +581,12 @@ class DATA_PT_context_arm(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -715,6 +740,12 @@ class DATA_PT_custom_props_arm(ArmatureButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -862,6 +893,12 @@ class DATA_PT_display(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1009,6 +1046,12 @@ class DATA_PT_ghost(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1159,6 +1202,12 @@ class DATA_PT_iksolver_itasc(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1309,6 +1358,12 @@ class DATA_PT_pose_library(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1456,6 +1511,12 @@ class DATA_PT_skeleton(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
