@@ -49,6 +49,12 @@ class TIME_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -192,6 +198,12 @@ class TIME_MT_autokey(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -240,7 +252,8 @@ class TIME_MT_autokey(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -341,6 +354,12 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -389,7 +408,8 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -499,6 +519,12 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -547,7 +573,8 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -648,6 +675,12 @@ class TIME_MT_frame(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -696,7 +729,8 @@ class TIME_MT_frame(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -797,6 +831,12 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -845,7 +885,8 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -946,6 +987,12 @@ class TIME_MT_playback(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -994,7 +1041,8 @@ class TIME_MT_playback(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1095,6 +1143,12 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1143,7 +1197,8 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
