@@ -56,9 +56,9 @@ def beautify_fill(bm: 'bmesh.types.BMesh',
 
 
 def bevel(bm: 'bmesh.types.BMesh',
-          geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                             List['bmesh.types.BMEdge'], typing.
-                             List['bmesh.types.BMVert']], offset: float,
+          geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                             List['bmesh.types.BMVert'], typing.
+                             List['bmesh.types.BMFace']], offset: float,
           offset_type: int, segments: int, profile: float, vertex_only: bool,
           clamp_overlap: bool, material: int, loop_slide: bool) -> dict:
     ''' Bevel. Bevels edges and vertices
@@ -66,7 +66,7 @@ def bevel(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input edges and vertices
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param offset: amount to offset beveled edge
     :type offset: float
     :param offset_type: how to measure offset (enum)
@@ -110,8 +110,8 @@ def bisect_edges(bm: 'bmesh.types.BMesh',
 
 def bisect_plane(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMFace'], typing.
-              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
+        Union[typing.List['bmesh.types.BMEdge'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
         dist: float, plane_co: typing.List['mathutils.Vector'],
         plane_no: typing.List['mathutils.Vector'], use_snap_center: bool,
         clear_outer: bool, clear_inner: bool) -> dict:
@@ -120,7 +120,7 @@ def bisect_plane(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param dist: minimum distance when testing if a vert is exactly on the plane
     :type dist: float
     :param plane_co: point on the plane
@@ -282,15 +282,15 @@ def connect_verts_nonplanar(bm: 'bmesh.types.BMesh', angle_limit: float,
 
 def contextual_create(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMFace'], typing.
-              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
+        Union[typing.List['bmesh.types.BMEdge'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
         mat_nr: int, use_smooth: bool) -> dict:
     ''' Contextual Create. This is basically F-key, it creates new faces from vertices, makes stuff from edge nets, makes wire edges, etc. It also dissolves faces. Three verts become a triangle, four become a quad. Two become a wire edge.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param mat_nr: material to use
     :type mat_nr: int
     :param use_smooth: smooth to use
@@ -302,16 +302,16 @@ def contextual_create(
 
 
 def convex_hull(bm: 'bmesh.types.BMesh',
-                input: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                                    List['bmesh.types.BMEdge'], typing.
-                                    List['bmesh.types.BMVert']],
+                input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                                    List['bmesh.types.BMVert'], typing.
+                                    List['bmesh.types.BMFace']],
                 use_existing_faces: bool) -> dict:
     ''' Convex Hull Builds a convex hull from the vertices in 'input'. If 'use_existing_faces' is true, the hull will not output triangles that are covered by a pre-existing face. All hull vertices, faces, and edges are added to 'geom.out'. Any input elements that end up inside the hull (i.e. are not used by an output face) are added to the 'interior_geom' slot. The 'unused_geom' slot will contain all interior geometry that is completely unused. Lastly, 'holes_geom' contains edges and faces that were in the input and are part of the hull.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: Undocumented.
-    :type input: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param use_existing_faces: Undocumented.
     :type use_existing_faces: bool
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_interior : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_unused : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_holes : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
@@ -491,15 +491,15 @@ def create_vert(bm: 'bmesh.types.BMesh',
 
 
 def delete(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                              List['bmesh.types.BMEdge'], typing.
-                              List['bmesh.types.BMVert']], context: int):
+           geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                              List['bmesh.types.BMVert'], typing.
+                              List['bmesh.types.BMFace']], context: int):
     ''' Delete Geometry. Utility operator to delete geometry.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param context: enum DEL_VERTS ...
     :type context: int
     '''
@@ -602,16 +602,16 @@ def dissolve_verts(bm: 'bmesh.types.BMesh',
 
 
 def duplicate(bm: 'bmesh.types.BMesh',
-              geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                                 List['bmesh.types.BMEdge'], typing.
-                                 List['bmesh.types.BMVert']],
+              geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                                 List['bmesh.types.BMVert'], typing.
+                                 List['bmesh.types.BMFace']],
               dest: 'bmesh.types.BMesh', use_select_history: bool) -> dict:
     ''' Duplicate Geometry. Utility operator to duplicate geometry, optionally into a destination mesh.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param dest: Undocumented.
     :type dest: 'bmesh.types.BMesh'
     :param use_select_history: Undocumented.
@@ -712,16 +712,16 @@ def extrude_edge_only(bm: 'bmesh.types.BMesh',
 
 def extrude_face_region(
         bm: 'bmesh.types.BMesh',
-        geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                           List['bmesh.types.BMEdge'], typing.
-                           List['bmesh.types.BMVert']], edges_exclude: set,
+        geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                           List['bmesh.types.BMVert'], typing.
+                           List['bmesh.types.BMFace']], edges_exclude: set,
         use_keep_orig: bool, use_select_history: bool) -> dict:
     ''' Extrude Faces. Extrude operator (does not transform)
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: edges and faces
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param edges_exclude: Undocumented.
     :type edges_exclude: set
     :param use_keep_orig: keep original geometry (requires geom to include edges).
@@ -937,9 +937,9 @@ def mesh_to_bmesh(bm: 'bmesh.types.BMesh', mesh: 'bpy.types.Mesh',
 
 
 def mirror(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                              List['bmesh.types.BMEdge'], typing.
-                              List['bmesh.types.BMVert']],
+           geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                              List['bmesh.types.BMVert'], typing.
+                              List['bmesh.types.BMFace']],
            matrix: 'mathutils.Matrix', merge_dist: float, axis: int,
            mirror_u: bool, mirror_v: bool) -> dict:
     ''' Mirror. Mirrors geometry along an axis. The resulting geometry is welded on using merge_dist. Pairs of original/mirrored vertices are welded using the merge_dist parameter (which defines the minimum distance for welding to happen).
@@ -947,7 +947,7 @@ def mirror(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param matrix: matrix defining the mirror transformation
     :type matrix: 'mathutils.Matrix'
     :param merge_dist: maximum distance for merging. does no merging if 0.
@@ -1082,15 +1082,15 @@ def recalc_face_normals(bm: 'bmesh.types.BMesh',
 
 def region_extend(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMFace'], typing.
-              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
+        Union[typing.List['bmesh.types.BMEdge'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
         use_contract: bool, use_faces: bool, use_face_step: bool) -> dict:
     ''' Region Extend. used to implement the select more/less tools. this puts some geometry surrounding regions of geometry in geom into geom.out. if use_faces is 0 then geom.out spits out verts and edges, otherwise it spits out faces.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param use_contract: find boundary inside the regions, not outside.
     :type use_contract: bool
     :param use_faces: extend from faces instead of edges
@@ -1368,16 +1368,16 @@ def smooth_vert(bm: 'bmesh.types.BMesh',
 
 
 def solidify(bm: 'bmesh.types.BMesh',
-             geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                                List['bmesh.types.BMEdge'], typing.
-                                List['bmesh.types.BMVert']],
+             geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                                List['bmesh.types.BMVert'], typing.
+                                List['bmesh.types.BMFace']],
              thickness: float) -> dict:
     ''' Solidify. Turns a mesh into a shell with thickness
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param thickness: Undocumented.
     :type thickness: float
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
@@ -1387,8 +1387,8 @@ def solidify(bm: 'bmesh.types.BMesh',
 
 
 def spin(bm: 'bmesh.types.BMesh', geom: typing.
-         Union[typing.List['bmesh.types.BMFace'], typing.
-               List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
+         Union[typing.List['bmesh.types.BMEdge'], typing.
+               List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
          cent: typing.List['mathutils.Vector'],
          axis: typing.List['mathutils.Vector'],
          dvec: typing.List['mathutils.Vector'], angle: float,
@@ -1398,7 +1398,7 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param cent: rotation center
     :type cent: typing.List['mathutils.Vector']
     :param axis: rotation axis
@@ -1420,15 +1420,15 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
 
 
 def split(bm: 'bmesh.types.BMesh', geom: typing.
-          Union[typing.List['bmesh.types.BMFace'], typing.
-                List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
+          Union[typing.List['bmesh.types.BMEdge'], typing.
+                List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
           dest: 'bmesh.types.BMesh', use_only_faces: bool) -> dict:
     ''' Split Off Geometry. Disconnect geometry from adjacent edges and faces, optionally into a destination mesh.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param dest: Undocumented.
     :type dest: 'bmesh.types.BMesh'
     :param use_only_faces: when enabled. don't duplicate loose verts/edges
@@ -1532,16 +1532,16 @@ def subdivide_edges(
 
 
 def symmetrize(bm: 'bmesh.types.BMesh',
-               input: typing.Union[typing.List['bmesh.types.BMFace'], typing.
-                                   List['bmesh.types.BMEdge'], typing.
-                                   List['bmesh.types.BMVert']], direction: int,
+               input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
+                                   List['bmesh.types.BMVert'], typing.
+                                   List['bmesh.types.BMFace']], direction: int,
                dist: float) -> dict:
     ''' Symmetrize. Makes the mesh elements in the "input" slot symmetrical. Unlike normal mirroring, it only copies in one direction, as specified by the "direction" slot. The edges and faces that cross the plane of symmetry are split as needed to enforce symmetry. All new vertices, edges, and faces are added to the "geom.out" slot.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: Undocumented.
-    :type input: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
+    :type input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
     :param direction: Undocumented.
     :type direction: int
     :param dist: minimum distance
