@@ -36,11 +36,11 @@ def bookmark_delete(index: int = -1):
     pass
 
 
-def bookmark_move(direction: typing.Union[int, str] = 'TOP'):
+def bookmark_move(direction: typing.Union[str, int] = 'TOP'):
     ''' Move the active bookmark up/down in the list
 
     :param direction: Direction, Direction to move the active bookmark towards * TOP Top, Top of the list. * UP Up. * DOWN Down. * BOTTOM Bottom, Bottom of the list.
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -128,8 +128,8 @@ def find_missing_files(
         filter_folder: bool = False,
         filter_blenlib: bool = False,
         filemode: int = 9,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Try to find missing external files
 
     :param find_all: Find All, Find all files in the search path (not just missing)
@@ -165,9 +165,9 @@ def find_missing_files(
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -334,13 +334,13 @@ def select_border(gesture_mode: int = 0,
     pass
 
 
-def select_walk(direction: typing.Union[int, str] = 'UP',
+def select_walk(direction: typing.Union[str, int] = 'UP',
                 extend: bool = False,
                 fill: bool = False):
     ''' Select/Deselect files by walking through them
 
     :param direction: Walk Direction, Select/Deselect file in this direction
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     :param fill: Fill, Select everything beginning with the last selection
@@ -358,23 +358,23 @@ def smoothscroll():
     pass
 
 
-def unpack_all(method: typing.Union[int, str] = 'USE_LOCAL'):
+def unpack_all(method: typing.Union[str, int] = 'USE_LOCAL'):
     ''' Unpack all files packed into this .blend to external ones
 
     :param method: Method, How to unpack
-    :type method: typing.Union[int, str]
+    :type method: typing.Union[str, int]
     '''
 
     pass
 
 
-def unpack_item(method: typing.Union[int, str] = 'USE_LOCAL',
+def unpack_item(method: typing.Union[str, int] = 'USE_LOCAL',
                 id_name: str = "",
                 id_type: int = 19785):
     ''' Unpack this file to an external file
 
     :param method: Method, How to unpack
-    :type method: typing.Union[int, str]
+    :type method: typing.Union[str, int]
     :param id_name: ID name, Name of ID block to unpack
     :type id_name: str
     :param id_type: ID Type, Identifier type of ID block
