@@ -37,11 +37,11 @@ def brush_add():
     pass
 
 
-def brush_change(brush: typing.Union[int, str] = 'DEFAULT'):
+def brush_change(brush: typing.Union[str, int] = 'DEFAULT'):
     ''' Change active Grease Pencil drawing brush
 
     :param brush: Grease Pencil Brush
-    :type brush: typing.Union[int, str]
+    :type brush: typing.Union[str, int]
     '''
 
     pass
@@ -55,11 +55,11 @@ def brush_copy():
     pass
 
 
-def brush_move(type: typing.Union[int, str] = 'UP'):
+def brush_move(type: typing.Union[str, int] = 'UP'):
     ''' Move the active Grease Pencil drawing brush up/down in the list
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -106,11 +106,11 @@ def brush_select(index: int = 0):
     pass
 
 
-def convert(type: typing.Union[int, str] = 'PATH',
+def convert(type: typing.Union[str, int] = 'PATH',
             use_normalize_weights: bool = True,
             radius_multiplier: float = 1.0,
             use_link_strokes: bool = True,
-            timing_mode: typing.Union[int, str] = 'FULL',
+            timing_mode: typing.Union[str, int] = 'FULL',
             frame_range: int = 100,
             start_frame: int = 1,
             use_realtime: bool = False,
@@ -122,7 +122,7 @@ def convert(type: typing.Union[int, str] = 'PATH',
     ''' Convert the active Grease Pencil layer to a new Curve Object
 
     :param type: Type, Which type of curve to convert to * PATH Path, Animation path. * CURVE Bezier Curve, Smooth Bezier curve. * POLY Polygon Curve, Bezier curve with straight-line segments (vector handles).
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param use_normalize_weights: Normalize Weight, Normalize weight (set from stroke width)
     :type use_normalize_weights: bool
     :param radius_multiplier: Radius Fac, Multiplier for the points' radii (set from stroke width)
@@ -130,7 +130,7 @@ def convert(type: typing.Union[int, str] = 'PATH',
     :param use_link_strokes: Link Strokes, Whether to link strokes with zero-radius sections of curves
     :type use_link_strokes: bool
     :param timing_mode: Timing Mode, How to use timing data stored in strokes * NONE No Timing, Ignore timing. * LINEAR Linear, Simple linear timing. * FULL Original, Use the original timing, gaps included. * CUSTOMGAP Custom Gaps, Use the original timing, but with custom gap lengths (in frames).
-    :type timing_mode: typing.Union[int, str]
+    :type timing_mode: typing.Union[str, int]
     :param frame_range: Frame Range, The duration of evaluation of the path control curve
     :type frame_range: int
     :param start_frame: Start Frame, The start frame of the path control curve
@@ -176,11 +176,11 @@ def data_unlink():
     pass
 
 
-def delete(type: typing.Union[int, str] = 'POINTS'):
+def delete(type: typing.Union[str, int] = 'POINTS'):
     ''' Delete selected Grease Pencil strokes, vertices, or frames
 
     :param type: Type, Method used for deleting Grease Pencil data * POINTS Points, Delete selected points and split strokes into segments. * STROKES Strokes, Delete selected strokes. * FRAME Frame, Delete active frame.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -194,7 +194,7 @@ def dissolve():
     pass
 
 
-def draw(mode: typing.Union[int, str] = 'DRAW',
+def draw(mode: typing.Union[str, int] = 'DRAW',
          stroke: typing.
          Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
                List['bpy.types.OperatorStrokeElement'],
@@ -203,7 +203,7 @@ def draw(mode: typing.Union[int, str] = 'DRAW',
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Grease Pencil strokes.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param stroke: Stroke
     :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
@@ -283,11 +283,11 @@ def layer_add():
     pass
 
 
-def layer_change(layer: typing.Union[int, str] = 'DEFAULT'):
+def layer_change(layer: typing.Union[str, int] = 'DEFAULT'):
     ''' Change active Grease Pencil layer
 
     :param layer: Grease Pencil Layer
-    :type layer: typing.Union[int, str]
+    :type layer: typing.Union[str, int]
     '''
 
     pass
@@ -319,11 +319,11 @@ def layer_merge():
     pass
 
 
-def layer_move(type: typing.Union[int, str] = 'UP'):
+def layer_move(type: typing.Union[str, int] = 'UP'):
     ''' Move the active Grease Pencil layer up/down in the list
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -345,11 +345,11 @@ def lock_all():
     pass
 
 
-def move_to_layer(layer: typing.Union[int, str] = 'DEFAULT'):
+def move_to_layer(layer: typing.Union[str, int] = 'DEFAULT'):
     ''' Move selected strokes to another layer
 
     :param layer: Grease Pencil Layer
-    :type layer: typing.Union[int, str]
+    :type layer: typing.Union[str, int]
     '''
 
     pass
@@ -363,11 +363,11 @@ def palette_add():
     pass
 
 
-def palette_change(palette: typing.Union[int, str] = 'DEFAULT'):
+def palette_change(palette: typing.Union[str, int] = 'DEFAULT'):
     ''' Change active Grease Pencil palette
 
     :param palette: Grease Pencil Palette
-    :type palette: typing.Union[int, str]
+    :type palette: typing.Union[str, int]
     '''
 
     pass
@@ -433,11 +433,11 @@ def palettecolor_lock_all():
     pass
 
 
-def palettecolor_move(direction: typing.Union[int, str] = 'UP'):
+def palettecolor_move(direction: typing.Union[str, int] = 'UP'):
     ''' Move the active Grease Pencil palette color up/down in the list
 
     :param direction: Direction
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -475,21 +475,21 @@ def palettecolor_unlock_all():
     pass
 
 
-def paste(type: typing.Union[int, str] = 'COPY'):
+def paste(type: typing.Union[str, int] = 'COPY'):
     ''' Paste previously copied strokes or copy and merge in active layer
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def reproject(type: typing.Union[int, str] = 'PLANAR'):
+def reproject(type: typing.Union[str, int] = 'PLANAR'):
     ''' Reproject the selected strokes from the current viewpoint as if they had been newly drawn (e.g. to fix problems from accidental 3D cursor movement or accidental viewport changes, or for matching deforming geometry)
 
     :param type: Projection Type * PLANAR Planar, Reproject the strokes to end up on the same plane, as if drawn from the current viewpoint using 'Cursor' Stroke Placement. * SURFACE Surface, Reproject the strokes on to the scene geometry, as if drawn using 'Surface' placement.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -525,11 +525,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all Grease Pencil strokes currently visible
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -591,11 +591,11 @@ def select_first(only_selected_strokes: bool = False, extend: bool = False):
     pass
 
 
-def select_grouped(type: typing.Union[int, str] = 'LAYER'):
+def select_grouped(type: typing.Union[str, int] = 'LAYER'):
     ''' Select all strokes with similar characteristics
 
     :param type: Type * LAYER Layer, Shared layers. * COLOR Color, Shared colors.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -697,11 +697,11 @@ def stroke_apply_thickness():
     pass
 
 
-def stroke_arrange(direction: typing.Union[int, str] = 'UP'):
+def stroke_arrange(direction: typing.Union[str, int] = 'UP'):
     ''' Arrange selected strokes up/down in the drawing order of the active layer
 
     :param direction: Direction
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -715,11 +715,11 @@ def stroke_change_color():
     pass
 
 
-def stroke_cyclical_set(type: typing.Union[int, str] = 'TOGGLE'):
+def stroke_cyclical_set(type: typing.Union[str, int] = 'TOGGLE'):
     ''' Close or open the selected stroke adding an edge from last to first point
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -733,12 +733,12 @@ def stroke_flip():
     pass
 
 
-def stroke_join(type: typing.Union[int, str] = 'JOIN',
+def stroke_join(type: typing.Union[str, int] = 'JOIN',
                 leave_gaps: bool = False):
     ''' Join selected strokes (optionally as new stroke)
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param leave_gaps: Leave Gaps, Leave gaps between joined strokes instead of linking them
     :type leave_gaps: bool
     '''
