@@ -99,11 +99,11 @@ def driver_variables_paste(replace: bool = False):
     pass
 
 
-def duplicate(mode: typing.Union[int, str] = 'TRANSLATION'):
+def duplicate(mode: typing.Union[str, int] = 'TRANSLATION'):
     ''' Make a copy of all selected keyframes
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -119,11 +119,11 @@ def duplicate_move(GRAPH_OT_duplicate=None, TRANSFORM_OT_transform=None):
     pass
 
 
-def easing_type(type: typing.Union[int, str] = 'AUTO'):
+def easing_type(type: typing.Union[str, int] = 'AUTO'):
     ''' Set easing type for the F-Curve segments starting from the selected keyframes
 
     :param type: Type * AUTO Automatic Easing, Easing type is chosen automatically based on what the type of interpolation used (e.g. 'Ease In' for transitional types, and 'Ease Out' for dynamic effects). * EASE_IN Ease In, Only on the end closest to the next keyframe. * EASE_OUT Ease Out, Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out, Segment between both keyframes.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -137,22 +137,22 @@ def euler_filter():
     pass
 
 
-def extrapolation_type(type: typing.Union[int, str] = 'CONSTANT'):
+def extrapolation_type(type: typing.Union[str, int] = 'CONSTANT'):
     ''' Set extrapolation mode for selected F-Curves
 
     :param type: Type * CONSTANT Constant Extrapolation, Values on endpoint keyframes are held. * LINEAR Linear Extrapolation, Straight-line slope of end segments are extended past the endpoint keyframes. * MAKE_CYCLIC Make Cyclic (F-Modifier), Add Cycles F-Modifier if one doesn't exist already. * CLEAR_CYCLIC Clear Cyclic (F-Modifier), Remove Cycles F-Modifier if not needed anymore.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def fmodifier_add(type: typing.Union[int, str] = 'NULL',
+def fmodifier_add(type: typing.Union[str, int] = 'NULL',
                   only_active: bool = True):
     ''' Add F-Modifier to the active/selected F-Curves
 
     :param type: Type * NULL Invalid. * GENERATOR Generator, Generate a curve using a factorized or expanded polynomial. * FNGENERATOR Built-In Function, Generate a curve using standard math functions such as sin and cos. * ENVELOPE Envelope, Reshape F-Curve values - e.g. change amplitude of movements. * CYCLES Cycles, Cyclic extend/repeat keyframe sequence. * NOISE Noise, Add pseudo-random noise on top of F-Curves. * LIMITS Limits, Restrict maximum and minimum values of F-Curve. * STEPPED Stepped Interpolation, Snap values to nearest grid-step - e.g. for a stop-motion look.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param only_active: Only Active, Only add F-Modifier to active F-Curve
     :type only_active: bool
     '''
@@ -204,11 +204,11 @@ def ghost_curves_create():
     pass
 
 
-def handle_type(type: typing.Union[int, str] = 'FREE'):
+def handle_type(type: typing.Union[str, int] = 'FREE'):
     ''' Set type of handle for selected keyframes
 
     :param type: Type * FREE Free. * VECTOR Vector. * ALIGNED Aligned. * AUTO Automatic. * AUTO_CLAMPED Auto Clamped, Auto handles clamped to not overshoot.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -224,45 +224,45 @@ def hide(unselected: bool = False):
     pass
 
 
-def interpolation_type(type: typing.Union[int, str] = 'CONSTANT'):
+def interpolation_type(type: typing.Union[str, int] = 'CONSTANT'):
     ''' Set interpolation mode for the F-Curve segments starting from the selected keyframes
 
     :param type: Type * CONSTANT Constant, No interpolation, value of A gets held until B is encountered. * LINEAR Linear, Straight-line interpolation between A and B (i.e. no ease in/out). * BEZIER Bezier, Smooth interpolation between A and B, with some control over curve shape. * SINE Sinusoidal, Sinusoidal easing (weakest, almost linear but with a slight curvature). * QUAD Quadratic, Quadratic easing. * CUBIC Cubic, Cubic easing. * QUART Quartic, Quartic easing. * QUINT Quintic, Quintic easing. * EXPO Exponential, Exponential easing (dramatic). * CIRC Circular, Circular easing (strongest and most dynamic). * BACK Back, Cubic easing with overshoot and settle. * BOUNCE Bounce, Exponentially decaying parabolic bounce, like when objects collide. * ELASTIC Elastic, Exponentially decaying sine wave, like an elastic band.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def keyframe_insert(type: typing.Union[int, str] = 'ALL'):
+def keyframe_insert(type: typing.Union[str, int] = 'ALL'):
     ''' Insert keyframes for the specified channels
 
     :param type: Type * ALL All Channels, Insert a keyframe on all visible and editable F-Curves using each curve's current value. * SEL Only Selected Channels, Insert a keyframe on selected F-Curves using each curve's current value. * CURSOR_ACTIVE Active Channels At Cursor, Insert a keyframe for the active F-Curve at the cursor point. * CURSOR_SEL Selected Channels At Cursor, Insert a keyframe for selected F-Curves at the cursor point.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def mirror(type: typing.Union[int, str] = 'CFRA'):
+def mirror(type: typing.Union[str, int] = 'CFRA'):
     ''' Flip selected keyframes over the selected mirror line
 
     :param type: Type * CFRA By Times over Current Frame, Flip times of selected keyframes using the current frame as the mirror line. * VALUE By Values over Cursor Value, Flip values of selected keyframes using the cursor value (Y/Horizontal component) as the mirror line. * YAXIS By Times over Time=0, Flip times of selected keyframes, effectively reversing the order they appear in. * XAXIS By Values over Value=0, Flip values of selected keyframes (i.e. negative values become positive, and vice versa). * MARKER By Times over First Selected Marker, Flip times of selected keyframes using the first selected marker as the reference point.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def paste(offset: typing.Union[int, str] = 'START',
-          merge: typing.Union[int, str] = 'MIX',
+def paste(offset: typing.Union[str, int] = 'START',
+          merge: typing.Union[str, int] = 'MIX',
           flipped: bool = False):
     ''' Paste keyframes from copy/paste buffer for the selected channels, starting on the current frame
 
     :param offset: Offset, Paste time offset of keys * START Frame Start, Paste keys starting at current frame. * END Frame End, Paste keys ending at current frame. * RELATIVE Frame Relative, Paste keys relative to the current frame when copying. * NONE No Offset, Paste keys from original time.
-    :type offset: typing.Union[int, str]
+    :type offset: typing.Union[str, int]
     :param merge: Type, Method of merging pasted keys and existing * MIX Mix, Overlay existing with new keys. * OVER_ALL Overwrite All, Replace all keys. * OVER_RANGE Overwrite Range, Overwrite keys in pasted range. * OVER_RANGE_ALL Overwrite Entire Range, Overwrite keys in pasted range, using the range of all copied keys.
-    :type merge: typing.Union[int, str]
+    :type merge: typing.Union[str, int]
     :param flipped: Flipped, Paste keyframes from mirrored bones if they exist
     :type flipped: bool
     '''
@@ -362,11 +362,11 @@ def select_circle(x: int = 0,
     pass
 
 
-def select_column(mode: typing.Union[int, str] = 'KEYS'):
+def select_column(mode: typing.Union[str, int] = 'KEYS'):
     ''' Select all keyframes on the specified frame(s)
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -390,12 +390,12 @@ def select_lasso(path: typing.Union[
     pass
 
 
-def select_leftright(mode: typing.Union[int, str] = 'CHECK',
+def select_leftright(mode: typing.Union[str, int] = 'CHECK',
                      extend: bool = False):
     ''' Select keyframes to the left or the right of the current frame
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param extend: Extend Select
     :type extend: bool
     '''
@@ -435,11 +435,11 @@ def smooth():
     pass
 
 
-def snap(type: typing.Union[int, str] = 'CFRA'):
+def snap(type: typing.Union[str, int] = 'CFRA'):
     ''' Snap selected keyframes to the chosen times/values
 
     :param type: Type * CFRA Current Frame, Snap selected keyframes to the current frame. * VALUE Cursor Value, Set values of selected keyframes to the cursor value (Y/Horizontal component). * NEAREST_FRAME Nearest Frame, Snap selected keyframes to the nearest (whole) frame (use to fix accidental sub-frame offsets). * NEAREST_SECOND Nearest Second, Snap selected keyframes to the nearest second. * NEAREST_MARKER Nearest Marker, Snap selected keyframes to the nearest marker. * HORIZONTAL Flatten Handles, Flatten handles for a smoother transition.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -462,8 +462,8 @@ def sound_bake(filepath: str = "",
                filemode: int = 9,
                show_multiview: bool = False,
                use_multiview: bool = False,
-               display_type: typing.Union[int, str] = 'DEFAULT',
-               sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+               display_type: typing.Union[str, int] = 'DEFAULT',
+               sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                low: float = 0.0,
                high: float = 100000.0,
                attack: float = 0.005,
@@ -510,9 +510,9 @@ def sound_bake(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param low: Lowest frequency, Cutoff frequency of a high-pass filter that is applied to the audio data
     :type low: float
     :param high: Highest frequency, Cutoff frequency of a low-pass filter that is applied to the audio data
