@@ -3,29 +3,29 @@ import typing
 
 
 def bvh(filepath: str = "",
-        axis_forward: typing.Union[int, str] = '-Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = '-Z',
+        axis_up: typing.Union[str, int] = 'Y',
         filter_glob: str = "*.bvh",
-        target: typing.Union[int, str] = 'ARMATURE',
+        target: typing.Union[str, int] = 'ARMATURE',
         global_scale: float = 1.0,
         frame_start: int = 1,
         use_fps_scale: bool = False,
         update_scene_fps: bool = False,
         update_scene_duration: bool = False,
         use_cyclic: bool = False,
-        rotate_mode: typing.Union[int, str] = 'NATIVE'):
+        rotate_mode: typing.Union[str, int] = 'NATIVE'):
     ''' Load a BVH motion capture file
 
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param target: Target, Import target type
-    :type target: typing.Union[int, str]
+    :type target: typing.Union[str, int]
     :param global_scale: Scale, Scale the BVH by this value
     :type global_scale: float
     :param frame_start: Start Frame, Starting frame for the animation
@@ -39,7 +39,7 @@ def bvh(filepath: str = "",
     :param use_cyclic: Loop, Loop the animation playback
     :type use_cyclic: bool
     :param rotate_mode: Rotation, Rotation conversion * QUATERNION Quaternion, Convert rotations to quaternions. * NATIVE Euler (Native), Use the rotation order defined in the BVH file. * XYZ Euler (XYZ), Convert rotations to euler XYZ. * XZY Euler (XZY), Convert rotations to euler XZY. * YXZ Euler (YXZ), Convert rotations to euler YXZ. * YZX Euler (YZX), Convert rotations to euler YZX. * ZXY Euler (ZXY), Convert rotations to euler ZXY. * ZYX Euler (ZYX), Convert rotations to euler ZYX.
-    :type rotate_mode: typing.Union[int, str]
+    :type rotate_mode: typing.Union[str, int]
     '''
 
     pass
