@@ -3,21 +3,21 @@ import typing
 import bpy.types
 
 
-def change_effect_input(swap: typing.Union[int, str] = 'A_B'):
+def change_effect_input(swap: typing.Union[str, int] = 'A_B'):
     ''' Undocumented
 
     :param swap: Swap, The effect inputs to swap
-    :type swap: typing.Union[int, str]
+    :type swap: typing.Union[str, int]
     '''
 
     pass
 
 
-def change_effect_type(type: typing.Union[int, str] = 'CROSS'):
+def change_effect_type(type: typing.Union[str, int] = 'CROSS'):
     ''' Undocumented
 
     :param type: Type, Sequencer effect type * CROSS Crossfade, Crossfade effect strip type. * ADD Add, Add effect strip type. * SUBTRACT Subtract, Subtract effect strip type. * ALPHA_OVER Alpha Over, Alpha Over effect strip type. * ALPHA_UNDER Alpha Under, Alpha Under effect strip type. * GAMMA_CROSS Gamma Cross, Gamma Cross effect strip type. * MULTIPLY Multiply, Multiply effect strip type. * OVER_DROP Alpha Over Drop, Alpha Over Drop effect strip type. * WIPE Wipe, Wipe effect strip type. * GLOW Glow, Glow effect strip type. * TRANSFORM Transform, Transform effect strip type. * COLOR Color, Color effect strip type. * SPEED Speed, Color effect strip type. * MULTICAM Multicam Selector. * ADJUSTMENT Adjustment Layer. * GAUSSIAN_BLUR Gaussian Blur. * TEXT Text.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -45,8 +45,8 @@ def change_path(
         filter_blenlib: bool = False,
         filemode: int = 9,
         relative_path: bool = True,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
         use_placeholders: bool = False):
     ''' Undocumented
 
@@ -87,9 +87,9 @@ def change_path(
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param use_placeholders: Use Placeholders, Use placeholders for missing frames of the strip
     :type use_placeholders: bool
     '''
@@ -114,16 +114,16 @@ def crossfade_sounds():
 
 
 def cut(frame: int = 0,
-        type: typing.Union[int, str] = 'SOFT',
-        side: typing.Union[int, str] = 'BOTH'):
+        type: typing.Union[str, int] = 'SOFT',
+        side: typing.Union[str, int] = 'BOTH'):
     ''' Cut the selected strips
 
     :param frame: Frame, Frame where selected strips will be cut
     :type frame: int
     :param type: Type, The type of cut operation to perform on strips
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param side: Side, The side that remains selected after cutting
-    :type side: typing.Union[int, str]
+    :type side: typing.Union[str, int]
     '''
 
     pass
@@ -155,11 +155,11 @@ def delete():
     pass
 
 
-def duplicate(mode: typing.Union[int, str] = 'TRANSLATION'):
+def duplicate(mode: typing.Union[str, int] = 'TRANSLATION'):
     ''' Duplicate the selected strips
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -180,7 +180,7 @@ def effect_strip_add(frame_start: int = 0,
                      channel: int = 1,
                      replace_sel: bool = True,
                      overlap: bool = False,
-                     type: typing.Union[int, str] = 'CROSS',
+                     type: typing.Union[str, int] = 'CROSS',
                      color: typing.List[float] = (0.0, 0.0, 0.0)):
     ''' Add an effect to the sequencer, most are applied on top of existing strips
 
@@ -195,7 +195,7 @@ def effect_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param type: Type, Sequencer effect type * CROSS Crossfade, Crossfade effect strip type. * ADD Add, Add effect strip type. * SUBTRACT Subtract, Subtract effect strip type. * ALPHA_OVER Alpha Over, Alpha Over effect strip type. * ALPHA_UNDER Alpha Under, Alpha Under effect strip type. * GAMMA_CROSS Gamma Cross, Gamma Cross effect strip type. * MULTIPLY Multiply, Multiply effect strip type. * OVER_DROP Alpha Over Drop, Alpha Over Drop effect strip type. * WIPE Wipe, Wipe effect strip type. * GLOW Glow, Glow effect strip type. * TRANSFORM Transform, Transform effect strip type. * COLOR Color, Color effect strip type. * SPEED Speed, Color effect strip type. * MULTICAM Multicam Selector. * ADJUSTMENT Adjustment Layer. * GAUSSIAN_BLUR Gaussian Blur. * TEXT Text.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param color: Color, Initialize the strip with this color (only used when type='COLOR')
     :type color: typing.List[float]
     '''
@@ -241,8 +241,8 @@ def export_subtitles(filepath: str = "",
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
-                     display_type: typing.Union[int, str] = 'DEFAULT',
-                     sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+                     display_type: typing.Union[str, int] = 'DEFAULT',
+                     sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Export .srt file containing text strips
 
     :param filepath: File Path, Path to file
@@ -278,9 +278,9 @@ def export_subtitles(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -329,8 +329,8 @@ def image_strip_add(
         relative_path: bool = True,
         show_multiview: bool = False,
         use_multiview: bool = False,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
         frame_start: int = 0,
         frame_end: int = 0,
         channel: int = 1,
@@ -378,9 +378,9 @@ def image_strip_add(
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param frame_end: End Frame, End frame for the color strip
@@ -420,7 +420,7 @@ def mask_strip_add(frame_start: int = 0,
                    channel: int = 1,
                    replace_sel: bool = True,
                    overlap: bool = False,
-                   mask: typing.Union[int, str] = ''):
+                   mask: typing.Union[str, int] = ''):
     ''' Add a mask strip to the sequencer
 
     :param frame_start: Start Frame, Start frame of the sequence strip
@@ -432,7 +432,7 @@ def mask_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param mask: Mask
-    :type mask: typing.Union[int, str]
+    :type mask: typing.Union[str, int]
     '''
 
     pass
@@ -485,8 +485,8 @@ def movie_strip_add(
         relative_path: bool = True,
         show_multiview: bool = False,
         use_multiview: bool = False,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
         frame_start: int = 0,
         channel: int = 1,
         replace_sel: bool = True,
@@ -534,9 +534,9 @@ def movie_strip_add(
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param channel: Channel, Channel to place this strip into
@@ -558,7 +558,7 @@ def movieclip_strip_add(frame_start: int = 0,
                         channel: int = 1,
                         replace_sel: bool = True,
                         overlap: bool = False,
-                        clip: typing.Union[int, str] = ''):
+                        clip: typing.Union[str, int] = ''):
     ''' Add a movieclip strip to the sequencer
 
     :param frame_start: Start Frame, Start frame of the sequence strip
@@ -570,7 +570,7 @@ def movieclip_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param clip: Clip
-    :type clip: typing.Union[int, str]
+    :type clip: typing.Union[str, int]
     '''
 
     pass
@@ -664,7 +664,7 @@ def scene_strip_add(frame_start: int = 0,
                     channel: int = 1,
                     replace_sel: bool = True,
                     overlap: bool = False,
-                    scene: typing.Union[int, str] = ''):
+                    scene: typing.Union[str, int] = ''):
     ''' Add a strip to the sequencer using a blender scene as a source
 
     :param frame_start: Start Frame, Start frame of the sequence strip
@@ -676,7 +676,7 @@ def scene_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param scene: Scene
-    :type scene: typing.Union[int, str]
+    :type scene: typing.Union[str, int]
     '''
 
     pass
@@ -684,7 +684,7 @@ def scene_strip_add(frame_start: int = 0,
 
 def select(extend: bool = False,
            linked_handle: bool = False,
-           left_right: typing.Union[int, str] = 'NONE',
+           left_right: typing.Union[str, int] = 'NONE',
            linked_time: bool = False):
     ''' Select a strip (last selected becomes the "active strip")
 
@@ -693,7 +693,7 @@ def select(extend: bool = False,
     :param linked_handle: Linked Handle, Select handles next to the active strip
     :type linked_handle: bool
     :param left_right: Left/Right, Select based on the current frame side the cursor is on * NONE None, Don't do left-right selection. * MOUSE Mouse, Use mouse position for selection. * LEFT Left, Select left. * RIGHT Right, Select right.
-    :type left_right: typing.Union[int, str]
+    :type left_right: typing.Union[str, int]
     :param linked_time: Linked Time, Select other strips at the same time
     :type linked_time: bool
     '''
@@ -701,21 +701,21 @@ def select(extend: bool = False,
     pass
 
 
-def select_active_side(side: typing.Union[int, str] = 'BOTH'):
+def select_active_side(side: typing.Union[str, int] = 'BOTH'):
     ''' Select strips on the nominated side of the active strip
 
     :param side: Side, The side of the handle that is selected
-    :type side: typing.Union[int, str]
+    :type side: typing.Union[str, int]
     '''
 
     pass
 
 
-def select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Select or deselect all strips
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -746,13 +746,13 @@ def select_border(gesture_mode: int = 0,
     pass
 
 
-def select_grouped(type: typing.Union[int, str] = 'TYPE',
+def select_grouped(type: typing.Union[str, int] = 'TYPE',
                    extend: bool = False,
                    use_active_channel: bool = False):
     ''' Select all strips grouped by various properties
 
     :param type: Type * TYPE Type, Shared strip type. * TYPE_BASIC Global Type, All strips of same basic type (Graphical or Sound). * TYPE_EFFECT Effect Type, Shared strip effect type (if active strip is not an effect one, select all non-effect strips). * DATA Data, Shared data (scene, image, sound, etc.). * EFFECT Effect, Shared effects. * EFFECT_LINK Effect/Linked, Other strips affected by the active one (sharing some time, and below or effect-assigned). * OVERLAP Overlap, Overlapping time.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     :param use_active_channel: Same Channel, Only consider strips on the same channel as the active one
@@ -762,11 +762,11 @@ def select_grouped(type: typing.Union[int, str] = 'TYPE',
     pass
 
 
-def select_handles(side: typing.Union[int, str] = 'BOTH'):
+def select_handles(side: typing.Union[str, int] = 'BOTH'):
     ''' Select manipulator handles on the sides of the selected strip
 
     :param side: Side, The side of the handle that is selected
-    :type side: typing.Union[int, str]
+    :type side: typing.Union[str, int]
     '''
 
     pass
@@ -847,8 +847,8 @@ def sound_strip_add(
         filter_blenlib: bool = False,
         filemode: int = 9,
         relative_path: bool = True,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
         frame_start: int = 0,
         channel: int = 1,
         replace_sel: bool = True,
@@ -892,9 +892,9 @@ def sound_strip_add(
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param channel: Channel, Channel to place this strip into
@@ -924,34 +924,34 @@ def strip_jump(next: bool = True, center: bool = True):
     pass
 
 
-def strip_modifier_add(type: typing.Union[int, str] = 'COLOR_BALANCE'):
+def strip_modifier_add(type: typing.Union[str, int] = 'COLOR_BALANCE'):
     ''' Add a modifier to the strip
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def strip_modifier_copy(type: typing.Union[int, str] = 'REPLACE'):
+def strip_modifier_copy(type: typing.Union[str, int] = 'REPLACE'):
     ''' Copy modifiers of the active strip to all selected strips
 
     :param type: Type * REPLACE Replace, Replace modifiers in destination. * APPEND Append, Append active modifiers to selected strips.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
 def strip_modifier_move(name: str = "Name",
-                        direction: typing.Union[int, str] = 'UP'):
+                        direction: typing.Union[str, int] = 'UP'):
     ''' Move modifier up and down in the stack
 
     :param name: Name, Name of modifier to remove
     :type name: str
     :param direction: Type * UP Up, Move modifier up in the stack. * DOWN Down, Move modifier down in the stack.
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -967,11 +967,11 @@ def strip_modifier_remove(name: str = "Name"):
     pass
 
 
-def swap(side: typing.Union[int, str] = 'RIGHT'):
+def swap(side: typing.Union[str, int] = 'RIGHT'):
     ''' Swap active strip with strip to the right or left
 
     :param side: Side, Side of the strip to swap
-    :type side: typing.Union[int, str]
+    :type side: typing.Union[str, int]
     '''
 
     pass
