@@ -159,5 +159,5 @@ def unpack_list(list_of_tuples):
 
 
 path_reference_mode = None
-''' constant value (<built-in function EnumProperty>, {'attr': 'path_mode', 'default': 'AUTO', 'items': (('AUTO', 'Auto', 'Use Relative paths with subdirectories only'), ('ABSOLUTE', 'Absolute', 'Always write absolute paths'), ('RELATIVE', 'Relative', 'Always write relative paths (where possible)'), ('MATCH', 'Match', 'Match Absolute/Relative setting with input path'), ('STRIP', 'Strip Path', 'Filename only'), ('COPY', 'Copy', 'Copy the file to the destination path (or subdirectory)')), 'description': 'Method used to reference paths', 'name': 'Path Mode'})
+''' constant value (<built-in function EnumProperty>, {'name': 'Path Mode', 'items': (('AUTO', 'Auto', 'Use Relative paths with subdirectories only'), ('ABSOLUTE', 'Absolute', 'Always write absolute paths'), ('RELATIVE', 'Relative', 'Always write relative paths (where possible)'), ('MATCH', 'Match', 'Match Absolute/Relative setting with input path'), ('STRIP', 'Strip Path', 'Filename only'), ('COPY', 'Copy', 'Copy the file to the destination path (or subdirectory)')), 'attr': 'path_mode', 'default': 'AUTO', 'description': 'Method used to reference paths'})
 '''
